https://git.reactos.org/?p=reactos.git;a=commitdiff;h=7068a790b2d9a24ff3cf8…
commit 7068a790b2d9a24ff3cf8856f40e8cac1eb6d05e
Author: Hermès Bélusca-Maïto <hermes.belusca-maito(a)reactos.org>
AuthorDate: Sun Sep 29 20:58:07 2024 +0200
Commit: Hermès Bélusca-Maïto <hermes.belusca-maito(a)reactos.org>
CommitDate: Tue Jan 28 22:00:54 2025 +0100
[NTOS:KD64] Add a missing KdEnteredDebugger reset in KdExitDebugger()
---
ntoskrnl/kd64/kdapi.c | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
diff --git a/ntoskrnl/kd64/kdapi.c b/ntoskrnl/kd64/kdapi.c
index 76f6786c112..dca8cc73cc2 100644
--- a/ntoskrnl/kd64/kdapi.c
+++ b/ntoskrnl/kd64/kdapi.c
@@ -1952,7 +1952,8 @@ KdExitDebugger(IN BOOLEAN Enable)
{
ULONG TimeSlip;
- /* Restore the state and unlock the port */
+ /* Reset the debugger entered flag, restore the port state and unlock it */
+ KdEnteredDebugger = FALSE;
KdRestore(FALSE);
if (KdpPortLocked) KdpPortUnlock();